@@ -8,22 +8,18 @@
     :license: MIT, see LICENSE for more details.
 """
 
-__version__ = '1.0'
+__version__ = '1.1'
 
 
 
 def listify(obj):
-    # Because None is used for specific functionality (auto-filling defaults),
-    # preserve it.
+    # Because None is used for specific functionality, preserve it.
     if obj is None:
         return None
 
-    if type(obj) is str:
-        obj = [obj, ]
-
     try:
-        assert hasattr(obj, '__len__')
-        assert obj.__len__
+        assert type(obj) is not str
+        assert hasattr(obj, '__iter__')
     except AssertionError:
         obj = [obj, ]
 
